@@ -5,9 +5,10 @@
 #' ConcHigh = Upper bound for an observed concentration
 #' Uncen    = 1 if uncensored, 0 if censored
 #'
-#' @param data dataframe contains at least dateTime, value, code columns
+#' @param data dataframe contains at least dateTime, code, value, columns in that order. 
+#' If there are more than the initial date, code, value...it combines the
+#' data is combined as using interval censored concepts. 
 #' @param verbose logical specifying whether or not to display progress message
-#' @param interactive logical deprecated. Use 'verbose' instead
 #' @keywords WRTDS flow
 #' @return data frame returnDataFrame data frame containing dateTime, ConcHigh, ConcLow, Uncen
 #' @export
@@ -23,13 +24,9 @@
 #'       comment2, value2, 
 #'       comment3, value3, stringsAsFactors=FALSE)
 #' compressData(dataInput)
-compressData <- function(data, verbose = TRUE, interactive=NULL){  
-  
-  if(!is.null(interactive)) {
-    warning("The argument 'interactive' is deprecated. Please use 'verbose' instead")
-    verbose <- interactive
-  }
+compressData <- function(data, verbose = TRUE){  
   
+
   data <- as.data.frame(data, stringsAsFactors=FALSE)
   numColumns <- ncol(data)
   numDataColumns <- (numColumns-1)/2
@@ -81,18 +78,6 @@ compressData <- function(data, verbose = TRUE, interactive=NULL){
       print(flaggedData1)
     }
   }
-  
-  # flaggedData2 <- returnDataFrame[(returnDataFrame$ConcLow > returnDataFrame$ConcHigh),]
-  # returnDataFrame <- returnDataFrame[(returnDataFrame$ConcLow <= returnDataFrame$ConcHigh),]
-  # 
-  # if (nrow(flaggedData2) > 0){
-  #   WarningMessage <- paste("Deleted", nrow(flaggedData2), "rows of data because the high concentration was reported lower than the low concentration, the program is unable to interpret that result and is therefore deleting it.")    
-  #   warning(WarningMessage)
-  #   if (verbose){
-  #     cat("Deleted Rows:\n")
-  #     print(flaggedData2)
-  #   }
-  #}
-  
+
   return(returnDataFrame)
 }
